==> tfjs-node-gpu-2.8.4.tgz: package/src/kernels/Mean.ts <==
/**
 * @license
 * Copyright 2020 Google LLC. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * =============================================================================
 */

import {cast, KernelConfig, Mean, MeanAttrs, MeanInputs, Tensor, tensor1d, util} from '@tensorflow/tfjs';

import {NodeJSKernelBackend} from '../nodejs_kernel_backend';

export const meanConfig: KernelConfig = {
  kernelName: Mean,
  backendName: 'tensorflow',
  kernelFunc: (args) => {
    const {x} = args.inputs as MeanInputs;
    const backend = args.backend as NodeJSKernelBackend;
    const {axis, keepDims} = args.attrs as {} as MeanAttrs;
    const axes = util.parseAxisParam(axis, x.shape);
    const axesTensor = tensor1d(axes, 'int32');

    // Cast to float32 to match existing tfjs implementation/tests.
    const asFloat32 = cast(x as Tensor, 'float32');
    const res = backend.executeSingleOutput(
        Mean, backend.createReductionOpAttrs(x, keepDims),
        [asFloat32, axesTensor]);

    asFloat32.dispose();
    axesTensor.dispose();
    return res;
  }
};

==> tfjs-node-gpu-4.7.0.tgz: package/src/kernels/Mean.ts <==
/**
 * @license
 * Copyright 2020 Google LLC. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * =============================================================================
 */

import {cast, KernelConfig, Mean, MeanAttrs, MeanInputs, Tensor, tensor1d, util} from '@tensorflow/tfjs';

import {NodeJSKernelBackend} from '../nodejs_kernel_backend';

export const meanConfig: KernelConfig = {
  kernelName: Mean,
  backendName: 'tensorflow',
  kernelFunc: (args) => {
    const {x} = args.inputs as MeanInputs;
    const backend = args.backend as NodeJSKernelBackend;
    const {axis, keepDims} = args.attrs as unknown as MeanAttrs;
    const axes = util.parseAxisParam(axis, x.shape);
    const axesTensor = tensor1d(axes, 'int32');

    // Cast to float32 to match existing tfjs implementation/tests.
    const asFloat32 = cast(x as Tensor, 'float32');
    const res = backend.executeSingleOutput(
        Mean, backend.createReductionOpAttrs(x, keepDims),
        [asFloat32, axesTensor]);

    asFloat32.dispose();
    axesTensor.dispose();
    return res;
  }
};
